Learn R Programming

Evapotranspiration (version 1.9)

ET.Abtew: Abtew Formulation

Description

Implementing the Abtew formulation for estimating actual evapotranspiration.

Usage

## S3 method for class 'Abtew':
ET(data, constants, ts="daily", solar="sunshine hours",\dots)

Arguments

data
A list of data in class "Abtew" which contains the following items (climate variables) required by Abtew formulation: Tmax, Tmin, Rs or n or Cd
constants
A list named constants consists of constants required for the calculation of Abtew formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vaporisation =
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Option for calculating solar radiation (i.e. the value of argument solar) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_Abtew.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Abtew actual evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Abtew actual evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Abtew actual evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Abtew actual evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Abtew actual evapotranspiration.
  • ET_formulationName of the formulation used which equals to Abtew.
  • ET_typeType of the estimation obtained which is Actual Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.

Details

The alternative calculation options can be selected through argument solar, please see Arguments for details.

References

Abtew, W. 1996. Evapotranspiration measurements and modeling for three wetland systems in south florida. Wiley Online Library.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.Abtew under the generic function ET
results <- ET.Abtew(data, constants,ts="daily", solar="sunshine hours")

Run the code above in your browser using DataLab