## S3 method for class 'BlaneyCriddle':
ET(data, constants, ts="daily", solar="sunshine hours", height = F , \dots)constants consists of constants required for the calculation of PenPan formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vaporisation daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.cloud:
sunshine hours indicates that solar radiation is to be calculated using the real data of sunshine hours;
cloud sunshine hours is to be estimated from cloud data.
DefaulT or F, indicating if adjustment for site elevation for arid and semi-arid regions is applied in Blaney-Criddle formulation (Allen and Brockway, 1983).
Default is F for no adjustment.solar)
- If height adjustment has been applied on results (i.e. the value of argument height)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_BlaneyCriddle.csv in the working directory:Blaney-Criddle.Reference Crop Evapotranspiration.solar, please see Arguments for details.
Height adjustment for the estimations is available through argument height, please see Arguments for details.ET,data,defaultconstants,constants# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.BlaneyCriddle under the generic function ET
results <- ET.BlaneyCriddle(data, constants, ts="daily", solar="sunshine hours", height= FALSE)Run the code above in your browser using DataLab