Learn R Programming

Evapotranspiration (version 1.9)

ET.BrutsaertStrickler: Brutsaert-Strickler Formulation

Description

Implementing the Brutsaert-Strickler formulation for actual areal evapotranspiration

Usage

## S3 method for class 'BrutsaertStrickler':
ET(data, constants, ts="daily", solar="sunshine hours", alpha=0.23, \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Brutsaert-Strickler formulation: Tmax, Tmin, RHmax, RHmin, Rs or n or Cd, u2 or uz
constants
A list named constants consists of constants required for the calculation of Brutsaert-Strickler formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of the evaporative surface representing the portion of the incident radiation that is reflected back at the surface. Default is 0.23 for surface covered with short reference crop.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Evaporative surface with values of albedo, surface resistance, crop height and roughness height - Option for calculating solar radiation (i.e. the value of argument solar) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_BrutsaertStrickler.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Brutsaert-Strickler actual areal evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Brutsaert-Strickler actual areal evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Brutsaert-Strickler actual areal evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Brutsaert-Strickler actual areal evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Brutsaert-Strickler actual areal evapotranspiration.
  • ET_formulationName of the formulation used which equals to Brutsaert-Strickler.
  • ET_typeType of the estimation obtained which is Actual Areal Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.

Details

The alternative calculation options can be selected through argument solar, please see Arguments for details. User-defined evaporative surface is allowed through argument alpha, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.BrutsaertStrickler under the generic function ET
results <- ET.BrutsaertStrickler(data, constants, ts="daily", solar="sunshine hours", alpha=0.23)

Run the code above in your browser using DataLab