Learn R Programming

Evapotranspiration (version 1.9)

ET.ChapmanAustralian: Chapman Formulation

Description

Implementing the Chapman formulation for estimating potential evapotranspiration.

Usage

## S3 method for class 'ChapmanAustralian':
ET(data, constants, ts="daily", PenPan= T, solar="sunshine hours", alpha=0.23, \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Chapman formulation: Tmax, Tmin, RHmax, RHmin, Rs or n or Cd, u2 or uz
constants
A list named constants consists of constants required for the calculation of Chapman formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vaporisation
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
PenPan
Must be T or F, indicating if the PenPan formulation is used for estimating Class-A pan evaporation required in Chapman formulation. If T PenPan will be used and if F the actual data of Class-A pan evapo
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of the evaporative surface incident radiation that is reflected back at the surface. Default is 0.23 for surface covered with short reference crop.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated, and the value of pan coefficient (only for when potential ET is estimated) - Evaporative surface with values of albedo - Option for calculating solar radiation (i.e. the value of argument solar) - If the PenPan formulation is used for estimating Class-A pan evaporation required in Chapman formulation (i.e. the value of argument PenPan) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_ChapmanAustralian.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Chapman potential evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Chapman potential evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Chapman equivalent Penmen-Monteith evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Chapman potential evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Chapman potential evapotranspiration.
  • ET_formulationName of the formulation used which equals to Chapman.
  • ET_typeType of the estimation obtained which is Potential Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.
  • message5A message to inform the users about if the Class-A pan evaporation is from actual data or from PenPan estimation.

Details

The alternative calculation options can be selected through arguments PenPan and solar, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Chapman, T. 2001, Estimation of evaporation in rainfall-runoff models, in F. Ghassemi, D. Post, M. SivapalanR. Vertessy (eds), MODSIM2001: Integrating models for Natural Resources Management across Disciplines, Issues and Scales, MSSANZ, vol. 1, pp. 293-298.

See Also

ET,data,defaultconstants,constants,ET.PenPan

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.ChapmanAustralian under the generic function ET
results <- ET.ChapmanAustralian(data, constants, ts="daily", PenPan= TRUE, 
solar="sunshine hours", alpha=0.23)

Run the code above in your browser using DataLab