Learn R Programming

Evapotranspiration (version 1.9)

ET.GrangerGray: Granger-Gray Formulation

Description

Implementing the Granger-Gray formulation for estimating actual areal evapotranspiration.

Usage

## S3 method for class 'GrangerGray':
ET(data, constants, ts="daily", solar="sunshine hours", 
windfunction_ver=1948, alpha=0.23, \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Granger-Gray formulation: Tmax, Tmin, RHmax, RHmin, Rs or n or Cd, u2 or uz
constants
A list named constants consists of constants required for the calculation of Granger-Gray formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vaporis
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
windfunction_ver
The version of Penman wind function that will be used within the Penman formulation. Must be either 1948 or 1956. 1948 is for applying the Penman's 1948 wind function (Penman, 1948); 1956 is for applyi
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface representing the portion of the incident radiation that is reflected back at the surface. Default is 0.23 for surface covered with short reference crop.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Evaporative surface with values of albedo - Option for calculating solar radiation (i.e. the value of argument solar) - The version of Penman wind function has been used (i.e. the value of argument windfunction_ver) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_GrangerGray.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Granger-Gray actual areal evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Granger-Gray actual areal evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Granger-Gray actual areal evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Granger-Gray actual areal evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Granger-Gray actual areal evapotranspiration.
  • ET_formulationName of the formulation used which equals to Granger-Gray.
  • ET_typeType of the estimation obtained which is Actual Areal Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.
  • message2A message to inform the users about which version of the Penman wind function has been used.

Details

The alternative calculation options can be selected through arguments solar and windfunction_ver, please see Arguments for details. User-defined evaporative surface is allowed through argument alpha, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Penman, H. L. 1948. Natural evaporation from open water, bare soil and grass. Proceedings of the Royal Society of London. Series A. Mathematical and Physical Sciences, 193, 120-145. Penman, H. L. 1956. Evaporation: An introductory survey. Netherlands Journal of Agricultural Science, 4, 9-29

See Also

ET,data,defaultconstants,constants,ET.Penman

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.GrangerGray under the generic function ET
results <- ET.GrangerGray(data, constants, ts="daily", 
solar="sunshine hours", windfunction_ver=1948, alpha=0.23)

Run the code above in your browser using DataLab