Learn R Programming

Evapotranspiration (version 1.9)

ET.Hamon: Hamon Formulation

Description

Implementing the Hamon formulation for estimating potential evapotranspiration.

Usage

## S3 method for class 'Hamon':
ET(data, constants = NULL, ts="daily", \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Hamon formulation: Tmax, Tmin
constants
Dummy argument with a NULL value.
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_Hamon.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Hamon potential evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Hamon potential evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Hamon potential evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Hamon potential evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Hamon potential evapotranspiration.
  • ET_formulationName of the formulation used which equals to Hamon.
  • ET_typeType of the estimation obtained which is Potential Evapotranspiration.

Details

This formulation provides a single calculation method with no alternatives available.

References

Hamon, W. R. 1961. Estimating potential evapotranspiration. Journal of the Hydraulics Division, 87, 107-120. Oudin, L., Hervieu, F., Michel, C., Perrin, C., Andreassian, V., Anctil, F.Loumagne, C. 2005, Which potential evapotranspiration input for a lumped rainfall-runoff model?: Part 2-Towards a simple and efficient potential evapotranspiration model for rainfall-runoff modelling. Journal of Hydrology, vol. 303, no. 1-4, pp. 290-306.

See Also

ET,data

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.Hamon under the generic function ET
results <- ET.Hamon(data, ts="daily")

Run the code above in your browser using DataLab