Learn R Programming

Evapotranspiration (version 1.9)

ET.HargreavesSamani: Hargreaves-Samani Formulation

Description

Implementing the Hargreaves-Samani formulation for estimating reference crop evapotranspiration.

Usage

## S3 method for class 'HargreavesSamani':
ET(data, constants, ts="daily", \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Hargreaves-Samani formulation: Tmax, Tmin
constants
A list named constants consists of constants required for the calculation of Hargreaves-Samani formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of va
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Evaporative surface with values of albedo - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values.
  • ET.DailyDaily aggregated estimations of Hargreaves-Samani reference crop evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Hargreaves-Samani reference crop evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Hargreaves-Samani reference crop evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Hargreaves-Samani reference crop evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Hargreaves-Samani reference crop evapotranspiration.
  • ET_formulationName of the formulation used which equals to Hargreaves-Samani.
  • ET_typeType of the estimation obtained which is Reference Crop Evapotranspiration.

Details

This formulation provides a single calculation method with no alternatives available.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Hargreaves, G.H.Samani, Z.A. 1985, Reference crop evapotranspiration from ambient air temperature. American Society of Agricultural Engineers.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.HargreavesSamani under the generic function ET
results <- ET.HargreavesSamani(data, constants, ts="daily")

Run the code above in your browser using DataLab