Learn R Programming

Evapotranspiration (version 1.9)

ET.Makkink: Makkink Formulation

Description

Implementing the Makkink formulation for estimating reference crop evapotranspiration.

Usage

## S3 method for class 'Makkink':
ET(data, constants, ts="daily", solar="sunshine hours", \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Makkink formulation: Tmax, Tmin, Rs or n or Cd
constants
A list named constants consists of constants required for the calculation of Makkink formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vaporisation
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Option for calculating solar radiation (i.e. the value of argument solar) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_Makkink.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Makkink reference crop evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Makkink reference crop evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Makkink reference crop evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Makkink reference crop evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Makkink reference crop evapotranspiration.
  • ET_formulationName of the formulation used which equals to Makkink.
  • ET_typeType of the estimation obtained which is Reference crop evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.

Details

The alternative calculation options can be selected through argument solar, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. De Bruin, H. 1981, The determination of (reference crop) evapotranspiration from routine weather data. Evaporation in relation to hydrology, pp. 25-37.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.Makkink under the generic function ET
results <- ET.Makkink(data, constants, ts="daily", solar="sunshine hours")

Run the code above in your browser using DataLab