Learn R Programming

Evapotranspiration (version 1.9)

ET.MattShuttleworth: Matt-Shuttleworth Formulation

Description

Implementing the Matt-Shuttleworth formulation for reference crop evapotranspiration

Usage

## S3 method for class 'MattShuttleworth':
ET(data, constants, ts="daily", solar="sunshine hours", alpha=0.23, r_s=70, CH=0.12, \dots)

Arguments

data
A list which contains the following items (climate variables) required by Matt-Shuttleworth formulation: Tmax, Tmin, RHmax, RHmin, Rs or n or Cd, u2 or uz
constants
A list named constants consists of constants required for the calculation of Matt-Shuttleworth formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of va
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface representing the portion of the incident radiation that is reflected back at the surface. Default is 0.23 for surface covered with short reference crop, which is for the cal
r_s
Any value (seconds per metre), surface resistance depends on the type of reference crop. Default is 70 for short reference crop.
CH
Any value (metres), crop height depends on the reference crop. Default is 0.12 for short reference crop.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Evaporative surface with values of albedo, surface resistance and crop height - Option for calculating solar radiation (i.e. the value of argument solar) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_MattShuttleworth.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Matt-Shuttleworth reference crop evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Matt-Shuttleworth reference crop evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Matt-Shuttleworth reference crop evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Matt-Shuttleworth reference crop evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Matt-Shuttleworth reference crop evapotranspiration.
  • ET_formulationName of the formulation used which equals to Matt-Shuttleworth.
  • ET_typeType of the estimation obtained which is Reference Crop Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.

Details

The alternative calculation options can be selected through argument solar, please see Arguments for details. User-defined evaporative surface is allowed through arguments alpha, r_s and CH, please see Arguments for details.

References

Shuttleworth, W. & Wallace, J. 2009. Calculating the water requirements of irrigated crops in Australia using the Matt-Shuttleworth approach. Transactions of the ASABE, 52, 1895-1906. McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.MattShuttleworth under the generic function ET
results <- ET.MattShuttleworth(data, constants, ts="daily",
solar="sunshine hours", alpha=0.23, r_s=70, CH=0.12)

Run the code above in your browser using DataLab