## S3 method for class 'McGuinnessBordne':
ET(data, constants, ts="daily", \dots)constants consists of constants required for the calculation of Jensen-Haise formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vaporisdaily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_McGuinnessBordne.csv in the working directory:McGuinness-Bordne.Potential Evapotranspiration.ET,data,defaultconstants,constants# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.McGuinnessBordne under the generic function ET
results <- ET.McGuinnessBordne(data, constants, ts="daily")Run the code above in your browser using DataLab