Learn R Programming

Evapotranspiration (version 1.9)

ET.MortonCRAE: Morton CRAE Formulation

Description

Implementing the Morton CRAE formulation for estimating potential evapotranspiration, wet-environment areal evapotranspiration and actual areal evapotranspiration.

Usage

## S3 method for class 'MortonCRAE':
ET(data, constants, ts="monthly", est="potential ET", 
solar="sunshine hours", Tdew= T, alpha = NULL, \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Morton CRAE formulation: Tmax, Tmin, Tdew, Rs or n or Cd
constants
A list named constants consists of constants required for the calculation of Morton CRAE formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lat_rad - latitude in radians, <
ts
Must be either monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is monthly.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
est
Must be either potential ET, wet areal ET or actual areal ET: potential ET proceeds to estimating potential evapotranspiration; wet areal ET proceeds to estimating wet-environmental areal ev
Tdew
Must be T or F, indicating if real data of dew point temperature is used for calculating the radiation in Morton's formulations, if T the data will be used and if F the dew point temperature will be calc
alpha
Only needed if argument solar has value of data. Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface representing the portion of the incident radiation that is reflected back at the surface. Default
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containign the following elements: - ET model name and ET quantity estimated (i.e. the value of argument est) - Option for calculating solar radiation (i.e. the value of argument solar) - If the actual dew point temperature data are used (i.e. the value of argument Tdew) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_MortonCRAE.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.
  • ET.AnnualA zoo object containing annually aggregated estimations of Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.
  • ET.MonthlyAveA zoo object containing monthly averaged estimations of daily Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.
  • ET.AnnualAveA zoo object containing annually averaged estimations of daily Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.
  • ET_formulationName of the formulation used which equals to MortonCRAE.
  • ET_typeType of the estimation obtained which is either Potential Evapotranspiration, Wet-environment Areal Evapotranspiration and Actual Areal Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.
  • message6A message to inform the users about if actual dew point temperature has been used in the calculations or alternative calculations has been performed without dew point temperature data.

Details

The type of evapotranspiration calculated can be selected through argument est, please see Arguments for details. The alternative calculation options can be selected through argument solar and Tdew, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Morton, F.I. 1983, Operational estimates of areal evapotranspiration and their significance to the science and practice of hydrology. Journal of Hydrology, vol. 66, no. 1-4, pp. 1-76.

See Also

data,defaultconstants,constants,ET.MortonCRWE

Examples

Run this code
# Use processed existing data set and constants from 
# kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.MortonCRAE under the generic function ET
results <- ET.MortonCRAE(data, constants, ts="monthly", 
est="potential ET", solar="sunshine hours", Tdew= TRUE, 
alpha = NULL)

Run the code above in your browser using DataLab