Learn R Programming

Evapotranspiration (version 1.9)

ET.PenPan: PenPan Formulation

Description

Implementing the PenPan formulation for Class-A pan evaporation.

Usage

## S3 method for class 'PenPan':
ET(data, constants, ts="daily", solar="sunshine hours", 
alpha=0.23, est="potential ET", pan_coeff=0.71, overest= F, 
\dots)

Arguments

data
A list of data which contains the following items (climate variables) required by PenPan formulation: Tmax, Tmin, RHmax, RHmin, Rs or n or Cd, u2 or uz
constants
A list named constants consists of constants required for the calculation of PenPan formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vaporisation
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of surface surrounding the evaporation pan representing the portion of the incident radiation that is reflected back at the surface. Default is 0.23 for surface covered with short reference crop.
overest
Must be T or F, indicating if adjustment for the overestimation (i.e. divided by 1.078) of Class-A pan evaporation for Australian data is applied in PenPan formulation. Default is F for no adjustment.
est
Must be either pan or potential ET to specify if estimation for the Class-A pan evaporation or potential evapotranspriation is performed. Default is potential ET for estimating potential evapotranspriation.
pan_coeff
Only required if argument est has value of potential ET, which defines the pan coefficient used to adjust the estimated pan evaporation to the potential ET required.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated (i.e. the value of argument est), and the value of pan coefficient (only for when potential ET is estimated) - Evaporative surface with values of albedo - Option for calculating solar radiation (i.e. the value of argument solar) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_PenPan.csv in the working directory:
  • ET.DailyDaily aggregated estimations of PenPan Class-A pan evaporation/potential evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of PenPan Class-A pan evaporation/potential evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of PenPan Class-A pan evaporation/potential evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily PenPan Class-A pan evaporation/potential evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily PenPan Class-A pan evaporation/potential evapotranspiration.
  • ET_formulationName of the formulation used which equals to PenPan.
  • ET_typeType of the estimation obtained which is Class-A Pan Evaporation or Potential Evapotranspiration depending on the value of est.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.

Details

The alternative calculation options can be selected through argument solar, please see Arguments for details. User-defined evaporative surface is allowed through argument alpha, please see Arguments for details. Adjustment for overestimation on the estimations are available through argument height, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Rotstayn, L. D., Roderick, M. L. & Farquhar, G. D. 2006. A simple pan-evaporation model for analysis of climate simulations: Evaluation over Australia. Geophysical Research Letters, 33.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from 
# kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.PenPan under the generic function ET
results <- ET.PenPan(data, constants, ts="daily", 
solar="sunshine hours", alpha=0.23,
est="potential ET", pan_coeff=0.71, overest= FALSE)

Run the code above in your browser using DataLab