Learn R Programming

Evapotranspiration (version 1.9)

ET.PenmanMonteith: Penman-Monteith Formulation

Description

Implementing the Penman-Monteith formulation (including the method for FAO-56 hypothetical short grass and the method for ASCE-EWRI Standardised crop) for estimating reference crop evapotranspiration

Usage

## S3 method for class 'PenmanMonteith':
ET(data, constants, ts="daily", solar="sunshine hours", wind="yes", crop="short", \dots)

Arguments

data
A list which contains the following items (climate variables) required by Penman-Monteith formulation: Tmax, Tmin, RHmax, RHmin, Rs or n or Cd, u2 or uz
constants
A list named constants consists of constants required for the calculation of Penman-Monteith formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vapo
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
wind
Must be either yes or no. yes indicates that the calculation will use real data of wind speed; no indicates that the alternative calculation without using wind data will be used in Penman formulation (V
crop
Must be either short or tall. short indicates that the method for FAO-56 hypothetical short grass will be applied (Allen et al., 1998, Equation 6); tall indicates that the method for ASCE-EWRI Standard
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Evaporative surface with values of albedo, surface resistance, crop height and roughness height - Option for calculating solar radiation (i.e. the value of argument solar) - If actual wind data has been used for calculation (i.e. the value of argument wind) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_PenmanMonteith.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Penman-Monteith rerference crop evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Penman-Monteith rerference crop evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Penman-Monteith rerference crop evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Penman-Monteith rerference crop evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Penman-Monteith rerference crop evapotranspiration.
  • ET_formulationName of the formulation used which equals to either Penman-Monteith FAO56 or Penman-Monteith ASCE-EWRI Standardised.
  • ET_typeA character string containing the type of the estimation obtained which is Reference Crop Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.
  • message2A message to inform the users about if actual wind data has been used in the calculations or alternative calculations has been performed without wind data.

Details

The alternative calculation options can be selected through arguments solar and wind, please see Arguments for details. User-defined evaporative surface is allowed through arguments crop, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Allen, R. G., Pereira, L. S., Raes, D. & Smith, M. 1998. Crop evapotranspiration-Guidelines for computing crop water requirements-FAO Irrigation and drainage. paper 56. FAO, Rome, 300, 6541. Allen, R. G. 2005. The ASCE standardized reference evapotranspiration equation. Amer Society of Civil Engineers.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.PenmanMonteith under the generic function ET
results <- ET.PenmanMonteith(data, constants, ts="daily", solar="sunshine hours", 
wind="yes", crop = "short")

Run the code above in your browser using DataLab