Arguments
data
A list of data in class "Penpan" which contains the following items (climate variables) required by Penpan formulation:
"Tmax", "Tmin", "RHmax", "RHmin", "Rs", "n" or "Cd", "u2" or "uz"
constants
A list named "constants" consists of constants required for the calculation of Penpan formulation which must contain the following items:
"Elev" - ground elevation above mean sea level in m,
"lambda" - latent heat of vaporisation = 2.45 MJ.kg^-1,
solar
Must be either "data", "sunshine hours", "cloud" or "monthly precipitation". "data" indicates that solar radiation data is to be used directly for calculating evapotranspiration; "sunshine hours" indicates that solar radiation is to be calculated using th
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface (or surrounding surface for Penpan formulation) representing the portion of the incident radiation that is reflected back at the surface.
overest
Must be TRUE or FALSE, indicating if adjustment for the overestimation (i.e. divided by 1.078) of Class-A pan evaporation for Australian data is applied in Penpan formulation.
...
Dummy for generic function, no need to define.