Learn R Programming

Evapotranspiration (version 1.9)

ET.PriestleyTaylor: Priestley-Taylor Formulation

Description

Implementing the Priestley-Taylor formulation for potential evaporation

Usage

## S3 method for class 'PriestleyTaylor':
ET(data, constants, ts="daily", solar="sunshine hours", alpha=0.23, \dots)

Arguments

data
A list which contains the following items (climate variables) required by Priestley-Taylor formulation: Tmax, Tmin, RHmax, RHmin, Rs or n or Cd
constants
A list named constants consists of constants required for the calculation of Priestley-Taylor formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vap
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface representing the portion of the incident radiation that is reflected back at the surface. Default is 0.23 for surface covered with short reference crop, which is for the cal
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Evaporative surface with values of albedo - Option for calculating solar radiation (i.e. the value of argument solar) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_PriestleyTaylor.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Priestley-Taylor potential evaporation.
  • ET.MonthlyMonthly aggregated estimations of Priestley-Taylor potential evaporation.
  • ET.AnnualAnnually aggregated estimations of Priestley-Taylor potential evaporation.
  • ET.MonthlyAveMonthly averaged estimations of daily Priestley-Taylor potential evaporation.
  • ET.AnnualAveAnnually averaged estimations of daily Priestley-Taylor potential evaporation.
  • ET_formulationA character string containing the name of the formulation used which equals to Priestley-Taylor.
  • ET_typeType of the estimation obtained which is Potential Evaporation.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.

Details

The alternative calculation options can be selected through argument solar, please see Arguments for details. User-defined evaporative surface is allowed through argument alpha, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Priestley, C. & Taylor, R. 1972, On the assessment of surface heat flux and evaporation using large-scale parameters'. Monthly Weather Review, vol. 100, no. 2, pp. 81-92.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.PriestleyTaylor under the generic function ET
results <- ET.PriestleyTaylor(data, constants, ts="daily", solar="sunshine hours", alpha=0.23)

Run the code above in your browser using DataLab