## S3 method for class 'SzilagyiJozsa':
ET(data, constants, ts="daily", solar="sunshine hours", wind="yes",
windfunction_ver=1948, alpha=0.23, z0=0.2, \dots)constants consists of constants required for the calculation of Szilagyi-Jozsa formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vapordaily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hoursyes or no.
yes indicates that the calculation will use real data of wind speed;
no indicates that the alternative calculation without using wind data will be used in Penman formulation (V1948 or 1956.
1948 is for applying the Penman's 1948 wind function (Penman, 1948);
1956 is for applyisolar)
- If actual wind data has been used for calculation (i.e. the value of argument wind) and which version of Penman wind function has been used (i.e. the value of argument windfunction_ver)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_SzilagyiJozsa.csv in the working directory:Szilagyi-Jozsa.Actual Evapotranspiration.solar, wind and windfunction_ver, please see Arguments for details.
User-defined evaporative surface is allowed through arguments alpha and z0, please see Arguments for details.ET,data,defaultconstants,constants,ET.Penman# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.SzilagyiJozsa under the generic function ET
results <- ET.SzilagyiJozsa(data, constants, ts="daily",
solar="sunshine hours", wind="yes", windfunction_ver=1948, alpha=0.23, z0=0.2)Run the code above in your browser using DataLab