Learn R Programming

Evapotranspiration (version 1.3)

ET.Truc: Truc Formulation

Description

Implementing the Truc formulation for estimating reference crop evapotranspiration.

Usage

## S3 method for class 'Truc':
ET(data, constants, solar, humid, \dots)

Arguments

data
A list of data in class "Truc" which contains the following items (climate variables) required by Truc formulation: "Tmax", "Tmin", "Rs", "n" or "Cd"
constants
A list named "constants" consists of constants required for the calculation of Truc formulation which must contain the following items: "Elev" - ground elevation above mean sea level in m, "lambda" - latent heat of vaporisation = 2.45 MJ.kg^-1, "
solar
Must be either "data", "sunshine hours", "cloud" or "monthly precipitation". "data" indicates that solar radiation is to be used directly for calculating evapotranspiration; "sunshine hours" indicates that solar radiation is to be calculated using the rea
humid
Must be TRUE or FALSE, indicating if adjustment for non-humid conditions is applied in Truc formulation (Alexandris et al., 2008, Equation 5b).
...
Dummy for generic function, no need to define.

Value

  • This function returns a object of class Truc. Such objects are list with components:
  • PET.DailyA zoo object containing daily aggregated estimations of Truc reference crop evapotranspiration.
  • PET.MonthlyA zoo object containing monthly aggregated estimations of Truc reference crop evapotranspiration.
  • PET.AnnualA zoo object containing annually aggregated estimations of Truc reference crop evapotranspiration.
  • PET.MonthlyAveA zoo object containing monthly averaged estimations of daily Truc reference crop evapotranspiration.
  • PET.AnnualAveA zoo object containing annually averaged estimations of daily Truc reference crop evapotranspiration.
  • PET_formulationA character string containing the name of the formulation used which equals to "Truc".
  • PET_typeA character string containing the type of the estimation obtained which is "Reference Crop Evapotranspiration".
  • message1A message to inform the users about how solar radiation has been calculated by using which data.
  • message4A message to inform the users about if adjustment for non-humid conditions has been applied to calculated Truc reference crop evapotranspiration.

Details

The alternative calculation options can be selected through argument solar, please see "Arguments" for details. Humidity adjustment for the estimations is available through argument humid, please see "Arguments" for details.

References

MCMAHON, T., PEEL, M., LOWE, L., SRIKANTHAN, R. & MCVICAR, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. TURC, L. 1961. Estimation of irrigation water requirements, potential evapotranspiration: a simple climatic formula evolved up to date. Ann. Agron, 12, 13-49. ALEXANDRIS, S., STRICEVIC, R. & PETKOVIC, S. 2008. Comparative analysis of reference evapotranspiration from the surface of rainfed grass in central Serbia, calculated by six empirical methods against the Penman-Monteith formula. Eur Water, 21, 17-28.

Examples

Run this code
# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")

# Set data class to be "Truc" to call function
funname <- "Truc" 
class(data) <- funname 

# Call generic function ET(data, ...) with class "Truc"
results <- ET(data, constants, solar="sunshine hours", humid = TRUE)

Run the code above in your browser using DataLab