Learn R Programming

Evapotranspiration (version 1.9)

ET.Turc: Turc Formulation

Description

Implementing the Turc formulation for estimating reference crop evapotranspiration.

Usage

## S3 method for class 'Turc':
ET(data, constants, ts="daily", solar="sunshine hours", humid= F, \dots)

Arguments

data
A list of data which contains the following items (climate variables) required by Turc formulation: Tmax, Tmin, Rs or n or Cd
constants
A list named constants consists of constants required for the calculation of Turc formulation which must contain the following items: Elev - ground elevation above mean sea level in m, lambda - latent heat of vaporisation =
ts
Must be either daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on. Default is daily.
solar
Must be either data, sunshine hours, cloud or monthly precipitation: data indicates that solar radiation data is to be used directly for calculating evapotranspiration; sunshine hours
humid
Must be T or F, indicating if adjustment for non-humid conditions is applied in Turc formulation (Alexandris et al., 2008, Equation 5b). Default is F for no adjustment.
...
Dummy for generic function, no need to define.

Value

  • The function prints a calculation summary to the screen containing the following elements: - ET model name and ET quantity estimated - Evaporative surface - Option for calculating solar radiation (i.e. the value of argument solar) - if adjustment for non-humid conditions has been applied (i.e. the value of argument humid) - Time step of the output ET estimates (i.e. the value of argument ts) - Units of the output ET estimates - Time duration of the ET estimation - Number of ET estimates obtained in the entire time-series - Basic statistics of the estimated ET time-series including mean, max and min values. The function also generates a list containing the following components, which is saved into a csv file named as ET_Turc.csv in the working directory:
  • ET.DailyDaily aggregated estimations of Turc reference crop evapotranspiration.
  • ET.MonthlyMonthly aggregated estimations of Turc reference crop evapotranspiration.
  • ET.AnnualAnnually aggregated estimations of Turc reference crop evapotranspiration.
  • ET.MonthlyAveMonthly averaged estimations of daily Turc reference crop evapotranspiration.
  • ET.AnnualAveAnnually averaged estimations of daily Turc reference crop evapotranspiration.
  • ET_formulationName of the formulation used which equals to Turc.
  • ET_typeType of the estimation obtained which is Reference Crop Evapotranspiration.
  • message1A message to inform the users about how solar radiation has been calculated by using which data.
  • message4A message to inform the users about if adjustment for non-humid conditions has been applied to calculated Turc reference crop evapotranspiration.

Details

The alternative calculation options can be selected through argument solar, please see Arguments for details. Humidity adjustment for the estimations is available through argument humid, please see Arguments for details.

References

McMahon, T., Peel, M., Lowe, L., Srikanthan, R. & McVicar, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. Turc, L. 1961, Estimation of irrigation water requirements, potential evapotranspiration: a simple climatic formula evolved up to date. Ann. Agron, vol. 12, no. 1, pp. 13-49. Alexandris, S., Stricevic, R.Petkovic, S. 2008, Comparative analysis of reference evapotranspiration from the surface of rainfed grass in central Serbia, calculated by six empirical methods against the Penman-Monteith formula. European Water, vol. 21, no. 22, pp. 17-28.

See Also

ET,data,defaultconstants,constants

Examples

Run this code
# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")

# Call ET.Turc under the generic function ET
results <- ET.Turc(data, constants, ts="daily", solar="sunshine hours", humid= FALSE)

Run the code above in your browser using DataLab