Usage
ETComparison(results1, results2, results3 = NULL, results4 = NULL, results5 = NULL,
results6 = NULL, results7 = NULL, labs, Sdate = NULL, Edate = NULL,
type = "Monthly", ylim = rep(NA,2))
Arguments
results1
A list named results which has been derived from function ET which can be from any model such as Penman, Penman-Monteith or Priestley-Taylor.
results2
A list named results which has been derived from function ET which can be from any model such as Penman, Penman-Monteith or Priestley-Taylor.
results3
A list named results which has been derived from function ET which can be from any model such as Penman, Penman-Monteith or Priestley-Taylor.
The default is NULL if the user requires the co
results4
A list named results which has been derived from function ET which can be from any model such as Penman, Penman-Monteith or Priestley-Taylor.
The default is NULL if the user requires the co
results5
A list named results which has been derived from function ET which can be from any model such as Penman, Penman-Monteith or Priestley-Taylor.
The default is NULL if the user requires the co
results6
A list named results which has been derived from function ET which can be from any model such as Penman, Penman-Monteith or Priestley-Taylor.
The default is NULL if the user requires the com
results7
A list named results which has been derived from function ET which can be from any model such as Penman, Penman-Monteith or Priestley-Taylor.
The default is NULL if the user requires the co
labs
A character vector with the length equal to the number of sets of results to compare, defining the labels for the comparison plots
Sdate
Only used when argument type is Daily, Monthly or Annual to define the start date for the plotting windows, which can be defined by user in the format YYYY-MM-DD; if missing the default is the f
Edate
Only used when argument type is Daily, Monthly or Annual to define the end date for the plotting windows, which can be defined by user in the format YYYY-MM-DD; if missing the default is the las
ylim
A numeric vector of length 2 defining the lower and upper limit of the y-axis for plotting, if missing the default is from 0 to 1.5 times of maximum value from the first set of result that is used to compare with others.
type
A character string indicating the type of plot produced, can be one of the following:
Daily - comparison plots of estimated daily evapotranspiration;
Monthly - comparison plots of monthly aggregated evapotranspiration;
Annu