data
A list of data in class "BrutsaertStrickler" which contains the following items (climate variables) required by Brutsaert-Strickler formulation:
"Ta", "vas", "vabar", "Tmax", "Tmin", "n" or "Cd" or "Precip", "u2" or "uz"
constants
A list named "constants" consists of constants required for the calculation of Brutsaert-Strickler formulation which must contain the following items:
"Elev" - ground elevation above mean sea level in m,
"lambda" - latent heat of vaporisation = 2.45
sunshine.hours
Must be either "data", "cloud" or "monthly precipitation". "data" indicates that solar radiation is to be calculated using the real data of sunshine hours; "cloud" sunshine hours is to be estimated from cloud data; "monthly precipitation" indicates that s
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface (or surrounding surface for Penpan formulation) representing the portion of the incident radiation that is reflected back at the surface.