Arguments
data
A list of data in class "GrangerGray" which contains the following items (climate variables) required by Granger-Gray formulation:
"Tmax", "Tmin", "RHmax", "RHmin", "Rs", "n" or "Cd", "u2" or "uz"
constants
A list named "constants" consists of constants required for the calculation of Granger-Gray formulation which must contain the following items:
"Elev" - ground elevation above mean sea level in m,
"lambda" - latent heat of vaporisation = 2.45 MJ.kg^
solar
Must be either "data", "sunshine hours", "cloud" or "monthly precipitation". "data" indicates that solar radiation data is to be used to calculate evapotranspiration; "sunshine hours" indicates that solar radiation is to be calculated using the real data
windfunction_ver
The version of Penman wind function that will be used within the Penman formulation. Must be either "1948" or "1956". "1948" is for applying the Penman's 1948 wind function (Penman, 1948); "1956" is for applying the Penman's 1956 wind function (Penman, 19
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface (or surrounding surface for Penpan formulation) representing the portion of the incident radiation that is reflected back at the surface.
...
Dummy for generic function, no need to define.