Learn R Programming

Evapotranspiration (version 1.1)

Evapotranspiration.McGuinnessBordne: McGuinness-Bordne Formulation

Description

Implementing the McGuinness-Bordne formulation for estimating potential evapotranspiration.

Usage

## S3 method for class 'McGuinnessBordne':
Evapotranspiration(data, constants, \dots)

Arguments

data
A list of data in class "McGuinnessBordne" which contains the following items (climate variables) required by McGuinness-Bordne formulation: "Tmax", "Tmin"
constants
A list named "constants" consists of constants required for the calculation of Penman formulation which must contain the following items: "Elev" - ground elevation above mean sea level in m, "lambda" - latent heat of vaporisation = 2.45 MJ.kg^-1,
...
Dummy for generic function, no need to define.

Value

  • This function returns a object of class McGuinnessBordne. Such objects are list with components:
  • PET.DailyA zoo object containing daily aggregated estimations of McGuinness-Bordne potential evapotranspiration.
  • PET.MonthlyA zoo object containing monthly aggregated estimations of McGuinness-Bordne potential evapotranspiration.
  • PET.AnnualA zoo object containing annually aggregated estimations of McGuinness-Bordne potential evapotranspiration.
  • PET.MonthlyAveA zoo object containing monthly averaged estimations of daily McGuinness-Bordne potential evapotranspiration.
  • PET.AnnualAveA zoo object containing annually averaged estimations of daily McGuinness-Bordne potential evapotranspiration.
  • PET_formulationA character string containing the name of the formulation used which equals to "McGuinness-Bordne".
  • PET_typeA character string containing the type of the estimation obtained which is "Potential Evapotranspiration".

Details

This formulation provides a single calculation method with no alternatives available.

References

MCMAHON, T., PEEL, M., LOWE, L., SRIKANTHAN, R. & MCVICAR, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. MCGUINNESS, J. L. & BORDNE, E. F. 1972. A comparison of lysimeter-derived potential evapotranspiration with computed values, US Dept. of Agriculture.

Examples

Run this code
# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")

# Set data class to be "McGuinnessBordne" to call function
funname <- "McGuinnessBordne" 
class(data) <- funname 

# Call generic function Evapotranspiration(data, ...) with class "McGuinnessBordne"
results <- Evapotranspiration(data, constants)

Run the code above in your browser using DataLab