Learn R Programming

Evapotranspiration (version 1.0)

Evapotranspiration.SzilagyiJozsa: Szilagyi-Jozsa Formulation

Description

Implementing the Szilagyi-Jozsa formulation for estimating actual evapotranspiration

Usage

## S3 method for class 'SzilagyiJozsa':
Evapotranspiration(data, constants, sunshine.hours, wind, 
windfunction_ver, alpha, z0, \dots)

Arguments

data
A list of data in class "SzilagyiJozsa" which contains the following items (climate variables) required by Szilagyi-Jozsa formulation: "Ta", "vas", "vabar", "Tmax", "Tmin", "n" or "Cd" or "Precip", "u2" or "uz" or "RHmean"
constants
A list named "constants" consists of constants required for the calculation of Szilagyi-Jozsa formulation which must contain the following items: "Elev" - ground elevation above mean sea level in m, "lambda" - latent heat of vaporisation = 2.45 MJ.k
sunshine.hours
Must be either "data", "cloud" or "monthly precipitation". "data" indicates that solar radiation is to be calculated using the real data of sunshine hours; "cloud" sunshine hours is to be estimated from cloud data; "monthly precipitation" indicates that s
wind
Must be either "yes" or "no". "yes" indicates that the calculation will use real data of wind speed for calculating Penman potential evapotranspiration, which is required for this formulation; "no" indicates that the alternative calculation without using
windfunction_ver
The version of Penman wind function that will be used within the Penman formulation. Must be either "1948" or "1956". "1948" is for applying the Penman's 1948 wind function (Penman, 1948); "1956" is for applying the Penman's 1956 wind function (Penman, 19
alpha
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface (or surrounding surface for Penpan formulation) representing the portion of the incident radiation that is reflected back at the surface.
z0
Any value (metres), roughness height of the evaporative surface.
...
Dummy for generic function, no need to define.

Value

  • This function returns a object of class SzilagyiJozsa. Such objects are list with components:
  • PET.DailyA zoo object containing daily aggregated estimations of Szilagyi-Jozsa actual evapotranspiration.
  • PET.MonthlyA zoo object containing monthly aggregated estimations of Szilagyi-Jozsa actual evapotranspiration.
  • PET.AnnualA zoo object containing annually aggregated estimations of Szilagyi-Jozsa actual evapotranspiration.
  • PET.MonthlyAveA zoo object containing monthly averaged estimations of daily Szilagyi-Jozsa actual evapotranspiration.
  • PET.AnnualAveA zoo object containing annually averaged estimations of daily Szilagyi-Jozsa actual evapotranspiration.
  • PET_formulationA character string containing the name of the formulation used which equals to "Szilagyi-Jozsa".
  • PET_typeA character string containing the type of the estimation obtained which is "Actual Evapotranspiration".
  • message1A message to inform the users about how solar radiation has been calculated by using which data.
  • message2A message to inform the users about if actual wind data has been used in the calculations or alternative calculations has been performed without wind data, and which version of the Penman wind function has been used.

Details

The alternative calculation options can be selected through arguments sunshine.hours, wind and windfunction_ver, please see "Arguments" for details. User-defined evaporative surface is allowed through arguments alpha and z0, please see "Arguments" for details.

References

SZILAGYI, J. 2007. On the inherent asymmetric nature of the complementary relationship of evaporation. Geophysical Research Letters, 34, L02405. MCMAHON, T., PEEL, M., LOWE, L., SRIKANTHAN, R. & MCVICAR, T. 2012. Estimating actual, potential, reference crop and pan evaporation using standard meteorological data: a pragmatic synthesis. Hydrology and Earth System Sciences Discussions, 9, 11829-11910. PENMAN, H. L. 1948. Natural evaporation from open water, bare soil and grass. Proceedings of the Royal Society of London. Series A. Mathematical and Physical Sciences, 193, 120-145. VALIANTZAS, J. D. 2006. Simplified versions for the Penman evaporation equation using routine weather data. Journal of Hydrology, 331, 690-702. PENMAN, H. L. 1956. Evaporation: An introductory survey. Netherlands Journal of Agricultural Science, 4, 9-29.

Examples

Run this code
# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")

# Set data class to be "SzilagyiJozsa" to call function
funname <- "SzilagyiJozsa"
class(data) <- funname

# Call generic function Evapotranspiration(data, ...) with class "SzilagyiJozsa"
results <- Evapotranspiration(data, constants, sunshine.hours="data", wind =
"yes", windfunction_ver = "1948", alpha = 0.23, z0 = 0.02)

Run the code above in your browser using DataLab