Learn R Programming

Evapotranspiration (version 1.2)

climatedata: Raw Climate Data Required for Calculating Evapotranspiration

Description

This data set contains the raw climate data including the variables required for calculating evapotranspiration in function Evapotranspiration over the observation period between 1/3/2001 and 08/31/2004 at the Kent Town station in Adelaide, Australia.

Usage

climatedata

Arguments

format

A list containing 11688 obserations of 30 variables

source

Bureau of Meteorology, Kent Town, Adelaide, Australia