## S3 method for class 'Abtew':
ET(data, constants, ts="daily", solar="sunshine hours",\dots)constants consists of constants required for the calculation of Abtew formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vaporisation =daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hourssolar)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_Abtew.csv in the working directory:Abtew.Actual Evapotranspiration.solar, please see Arguments for details.ET,data,defaultconstants,constants# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.Abtew under the generic function ET
results <- ET.Abtew(data, constants,ts="daily", solar="sunshine hours")Run the code above in your browser using DataLab