## S3 method for class 'ChapmanAustralian':
ET(data, constants, ts="daily", PenPan= T, solar="sunshine hours", alpha=0.23, \dots)constants consists of constants required for the calculation of Chapman formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vaporisationdaily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.T or F, indicating if the PenPan formulation is used for estimating Class-A pan evaporation required in Chapman formulation. If T PenPan will be used and if F the actual data of Class-A pan evapodata, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hourssolar)
- If the PenPan formulation is used for estimating Class-A pan evaporation required in Chapman formulation (i.e. the value of argument PenPan)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_ChapmanAustralian.csv in the working directory:Chapman.Potential Evapotranspiration.PenPan and solar, please see Arguments for details.ET,data,defaultconstants,constants,ET.PenPan# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.ChapmanAustralian under the generic function ET
results <- ET.ChapmanAustralian(data, constants, ts="daily", PenPan= TRUE,
solar="sunshine hours", alpha=0.23)Run the code above in your browser using DataLab