## S3 method for class 'GrangerGray':
ET(data, constants, ts="daily", solar="sunshine hours",
windfunction_ver=1948, alpha=0.23, \dots)constants consists of constants required for the calculation of Granger-Gray formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vaporisdaily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hours1948 or 1956.
1948 is for applying the Penman's 1948 wind function (Penman, 1948);
1956 is for applyisolar)
- The version of Penman wind function has been used (i.e. the value of argument windfunction_ver)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_GrangerGray.csv in the working directory:Granger-Gray.Actual Areal Evapotranspiration.solar and windfunction_ver, please see Arguments for details.
User-defined evaporative surface is allowed through argument alpha, please see Arguments for details.ET,data,defaultconstants,constants,ET.Penman# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.GrangerGray under the generic function ET
results <- ET.GrangerGray(data, constants, ts="daily",
solar="sunshine hours", windfunction_ver=1948, alpha=0.23)Run the code above in your browser using DataLab