## S3 method for class 'GrangerGray':
ET(data, constants, solar, windfunction_ver, alpha, \dots)GrangerGray. Such objects are list with components:zoo object containing daily aggregated estimations of Granger-Gray actual areal evapotranspiration.zoo object containing monthly aggregated estimations of Granger-Gray actual areal evapotranspiration.zoo object containing annually aggregated estimations of Granger-Gray actual areal evapotranspiration.zoo object containing monthly averaged estimations of daily Granger-Gray actual areal evapotranspiration.zoo object containing annually averaged estimations of daily Granger-Gray actual areal evapotranspiration.solar and windfunction_ver, please see "Arguments" for details.
User-defined evaporative surface is allowed through argument alpha, please see "Arguments" for details.# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")
# Set data class to be "GrangerGray" to call function
funname <- "GrangerGray"
class(data) <- funname
# Call generic function ET(data, ...) with class "GrangerGray"
results <- ET(data, constants, solar="sunshine hours", windfunction_ver =
"1948", alpha = 0.23)Run the code above in your browser using DataLab