## S3 method for class 'MattShuttleworth':
ET(data, constants, ts="daily", solar="sunshine hours", alpha=0.23, r_s=70, CH=0.12, \dots)constants consists of constants required for the calculation of Matt-Shuttleworth formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vadaily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hourssolar)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_MattShuttleworth.csv in the working directory:solar, please see Arguments for details.
User-defined evaporative surface is allowed through arguments alpha, r_s and CH, please see Arguments for details.ET,data,defaultconstants,constants# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.MattShuttleworth under the generic function ET
results <- ET.MattShuttleworth(data, constants, ts="daily",
solar="sunshine hours", alpha=0.23, r_s=70, CH=0.12)Run the code above in your browser using DataLab