## S3 method for class 'MortonCRAE':
ET(data, constants, ts="monthly", est="potential ET",
solar="sunshine hours", Tdew= T, alpha = NULL, \dots)constants consists of constants required for the calculation of Morton CRAE formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lat_rad - latitude in radians,
<monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is monthly.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hourspotential ET, wet areal ET or actual areal ET:
potential ET proceeds to estimating potential evapotranspiration;
wet areal ET proceeds to estimating wet-environmental areal evT or F, indicating if real data of dew point temperature is used for calculating the radiation in Morton's formulations, if T the data will be used and if F the dew point temperature will be calcsolar has value of data.
Any numeric value between 0 and 1 (dimensionless), albedo of evaporative surface representing the portion of the incident radiation that is reflected back at the surface.
Defaultest)
- Option for calculating solar radiation (i.e. the value of argument solar)
- If the actual dew point temperature data are used (i.e. the value of argument Tdew)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_MortonCRAE.csv in the working directory:zoo object containing annually aggregated estimations of Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.zoo object containing monthly averaged estimations of daily Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.zoo object containing annually averaged estimations of daily Morton CRAE potential evapotranspiration, wet-environment areal evapotranspiration or actual areal evapotranspiration.MortonCRAE.Potential Evapotranspiration, Wet-environment Areal Evapotranspiration and Actual Areal Evapotranspiration.est, please see Arguments for details.
The alternative calculation options can be selected through argument solar and Tdew, please see Arguments for details.data,defaultconstants,constants,ET.MortonCRWE# Use processed existing data set and constants from
# kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.MortonCRAE under the generic function ET
results <- ET.MortonCRAE(data, constants, ts="monthly",
est="potential ET", solar="sunshine hours", Tdew= TRUE,
alpha = NULL)Run the code above in your browser using DataLab