## S3 method for class 'MortonCRWE':
ET(data, constants, est, solar, Tdew, \dots)MortonCRWE. Such objects are list with components:zoo object containing daily aggregated estimations of MortonCRWE potential evapotranspiration or shallow lake evaporation.zoo object containing monthly aggregated estimations of MortonCRWE potential evapotranspiration or shallow lake evaporation.zoo object containing annually aggregated estimations of MortonCRWE potential evapotranspiration or shallow lake evaporation.zoo object containing monthly averaged estimations of daily MortonCRWE potential evapotranspiration or shallow lake evaporation.zoo object containing annually averaged estimations of daily MortonCRWE potential evapotranspiration or shallow lake evaporation.est, please see "Arguments" for details.
The alternative calculation options can be selected through argument solar and Tdew, please see "Arguments" for details.# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")
# Set data class to be "MortonCRWE" to call function
funname <- "MortonCRWE"
class(data) <- funname
# Call generic function ET(data, ...) with class "MortonCRWE"
results <- ET(data, constants, est = "potential", solar =
"sunshine hours", Tdew = TRUE)Run the code above in your browser using DataLab