## S3 method for class 'PenPan':
ET(data, constants, ts="daily", solar="sunshine hours",
alpha=0.23, est="potential ET", pan_coeff=0.71, overest= F,
\dots)constants consists of constants required for the calculation of PenPan formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vaporisation daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hoursT or F, indicating if adjustment for the overestimation (i.e. divided by 1.078) of Class-A pan evaporation for Australian data is applied in PenPan formulation.
Default is F for no adjustment.pan or potential ET to specify if estimation for the Class-A pan evaporation or potential evapotranspriation is performed.
Default is potential ET for estimating potential evapotranspriation.est has value of potential ET, which defines the pan coefficient used to adjust the estimated pan evaporation to the potential ET required.est), and the value of pan coefficient (only for when potential ET is estimated)
- Evaporative surface with values of albedo
- Option for calculating solar radiation (i.e. the value of argument solar)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_PenPan.csv in the working directory:PenPan.Class-A Pan Evaporation or Potential Evapotranspiration depending on the value of est.solar, please see Arguments for details.
User-defined evaporative surface is allowed through argument alpha, please see Arguments for details.
Adjustment for overestimation on the estimations are available through argument height, please see Arguments for details.ET,data,defaultconstants,constants# Use processed existing data set and constants from
# kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.PenPan under the generic function ET
results <- ET.PenPan(data, constants, ts="daily",
solar="sunshine hours", alpha=0.23,
est="potential ET", pan_coeff=0.71, overest= FALSE)Run the code above in your browser using DataLab