## S3 method for class 'Penman':
ET(data, constants, solar, wind, windfunction_ver,
alpha = 0.08, z0 = 0.001, \dots)Penman. Such objects are list with components:zoo object containing daily aggregated estimations of Penman open-water evaporation or potential evapotranspiration.zoo object containing monthly aggregated estimations of Penman open-water evaporation or potential evapotranspiration.zoo object containing annually aggregated estimations of Penman open-water evaporation or potential evapotranspiration.zoo object containing monthly averaged estimations of daily Penman open-water evaporation or potential evapotranspiration.zoo object containing annually averaged estimations of daily Penman open-water evaporation or potential evapotranspiration.solar, wind and windfunction_ver, please see "Arguments" for details.
User-defined evaporative surface is allowed through arguments alpha and z0, please see "Arguments" for details.# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")
# Set data class to be "Penman" to call function
funname <- "Penman"
class(data) <- funname
# Call generic function ET(data, ...) with class "Penman"
results <- ET(data, constants, solar="sunshine hours", wind=
"yes", windfunction_ver = "1948", alpha = 0.08, z0 = 0.001)Run the code above in your browser using DataLab