## S3 method for class 'PenmanMonteith':
ET(data, constants, ts="daily", solar="sunshine hours", wind="yes", crop="short", \dots)constants consists of constants required for the calculation of Penman-Monteith formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vapodaily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hoursyes or no.
yes indicates that the calculation will use real data of wind speed;
no indicates that the alternative calculation without using wind data will be used in Penman formulation (Vshort or tall.
short indicates that the method for FAO-56 hypothetical short grass will be applied (Allen et al., 1998, Equation 6);
tall indicates that the method for ASCE-EWRI Standardsolar)
- If actual wind data has been used for calculation (i.e. the value of argument wind)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_PenmanMonteith.csv in the working directory:Penman-Monteith FAO56 or Penman-Monteith ASCE-EWRI Standardised.Reference Crop Evapotranspiration.solar and wind, please see Arguments for details.
User-defined evaporative surface is allowed through arguments crop, please see Arguments for details.ET,data,defaultconstants,constants# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.PenmanMonteith under the generic function ET
results <- ET.PenmanMonteith(data, constants, ts="daily", solar="sunshine hours",
wind="yes", crop = "short")Run the code above in your browser using DataLab