## S3 method for class 'PenmanMonteith':
ET(data, constants, solar, wind, crop, \dots)PenmanMonteith. Such objects are list with components:zoo object containing daily aggregated estimations of Penman-Monteith rerference crop evapotranspiration.zoo object containing monthly aggregated estimations of Penman-Monteith rerference crop evapotranspiration.zoo object containing annually aggregated estimations of Penman-Monteith rerference crop evapotranspiration.zoo object containing monthly averaged estimations of daily Penman-Monteith rerference crop evapotranspiration.zoo object containing annually averaged estimations of daily Penman-Monteith rerference crop evapotranspiration.solar and wind, please see "Arguments" for details.
User-defined evaporative surface is allowed through arguments crop, please see "Arguments" for details.# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")
# Set data class to be "PenmanMonteith" to call function
funname <- "PenmanMonteith"
class(data) <- funname
# Call generic function ET(data, ...) with class "PenmanMonteith"
results <- ET(data, constants, solar="sunshine hours", wind="yes", crop="short")Run the code above in your browser using DataLab