## S3 method for class 'Truc':
ET(data, constants, solar, humid, \dots)Truc. Such objects are list with components:zoo object containing daily aggregated estimations of Truc reference crop evapotranspiration.zoo object containing monthly aggregated estimations of Truc reference crop evapotranspiration.zoo object containing annually aggregated estimations of Truc reference crop evapotranspiration.zoo object containing monthly averaged estimations of daily Truc reference crop evapotranspiration.zoo object containing annually averaged estimations of daily Truc reference crop evapotranspiration.solar, please see "Arguments" for details.
Humidity adjustment for the estimations is available through argument humid, please see "Arguments" for details.# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")
# Set data class to be "Truc" to call function
funname <- "Truc"
class(data) <- funname
# Call generic function ET(data, ...) with class "Truc"
results <- ET(data, constants, solar="sunshine hours", humid = TRUE)Run the code above in your browser using DataLab