## S3 method for class 'Turc':
ET(data, constants, ts="daily", solar="sunshine hours", humid= F, \dots)constants consists of constants required for the calculation of Turc formulation which must contain the following items:
Elev - ground elevation above mean sea level in m,
lambda - latent heat of vaporisation = daily, monthly or annual, which indicates the disired time step that the output ET estimates should be on.
Default is daily.data, sunshine hours, cloud or monthly precipitation:
data indicates that solar radiation data is to be used directly for calculating evapotranspiration;
sunshine hoursT or F, indicating if adjustment for non-humid conditions is applied in Turc formulation (Alexandris et al., 2008, Equation 5b).
Default is F for no adjustment.solar)
- if adjustment for non-humid conditions has been applied (i.e. the value of argument humid)
- Time step of the output ET estimates (i.e. the value of argument ts)
- Units of the output ET estimates
- Time duration of the ET estimation
- Number of ET estimates obtained in the entire time-series
- Basic statistics of the estimated ET time-series including mean, max and min values.
The function also generates a list containing the following components, which is saved into a csv file named as ET_Turc.csv in the working directory:Turc.Reference Crop Evapotranspiration.solar, please see Arguments for details.
Humidity adjustment for the estimations is available through argument humid, please see Arguments for details.ET,data,defaultconstants,constants# Use processed existing data set and constants from kent Town, Adelaide
data("processeddata")
data("constants")
# Call ET.Turc under the generic function ET
results <- ET.Turc(data, constants, ts="daily", solar="sunshine hours", humid= FALSE)Run the code above in your browser using DataLab