## S3 method for class 'SzilagyiJozsa':
Evapotranspiration(data, constants, sunshine.hours, wind,
windfunction_ver, alpha, z0, \dots)SzilagyiJozsa. Such objects are list with components:zoo object containing daily aggregated estimations of Szilagyi-Jozsa actual evapotranspiration.zoo object containing monthly aggregated estimations of Szilagyi-Jozsa actual evapotranspiration.zoo object containing annually aggregated estimations of Szilagyi-Jozsa actual evapotranspiration.zoo object containing monthly averaged estimations of daily Szilagyi-Jozsa actual evapotranspiration.zoo object containing annually averaged estimations of daily Szilagyi-Jozsa actual evapotranspiration.sunshine.hours, wind and windfunction_ver, please see "Arguments" for details.
User-defined evaporative surface is allowed through arguments alpha and z0, please see "Arguments" for details.# Use processed existing data set from kent Town, Adelaide
data("processeddata")
data("constants")
# Set data class to be "SzilagyiJozsa" to call function
funname <- "SzilagyiJozsa"
class(data) <- funname
# Call generic function Evapotranspiration(data, ...) with class "SzilagyiJozsa"
results <- Evapotranspiration(data, constants, sunshine.hours="data", wind =
"yes", windfunction_ver = "1948", alpha = 0.23, z0 = 0.02)Run the code above in your browser using DataLab